@@ -2,9 +2,10 @@
 
 from pathlib import Path
 
-from astropy import log
 import click
 import pyregion
+from astropy import log
+
 from regions import read_ds9
 
 log.setLevel('DEBUG')
@@ -20,7 +21,7 @@ def cli():
 
 @cli.command('list-files')
 def list_files():
-    print("Available files")
+    print('Available files')
     for ffile in TEST_FILE_DIR.glob('*.reg'):
         print(ffile.parts[-1])
 
