@@ -6,14 +6,12 @@ handling.
 
 # Affiliated packages may add whatever they like to this file, but
 # should keep this content at the top.
-# ----------------------------------------------------------------------------
-from ._astropy_init import *  # noqa
-# ----------------------------------------------------------------------------
+from ._astropy_init import *  # noqa: F401, F403
 
-from .core import *  # noqa
-from .io import *  # noqa
-from .shapes import *  # noqa
-from ._utils.examples import *  # noqa
+from ._utils.examples import *  # noqa: F401, F403
+from .core import *  # noqa: F401, F403
+from .io import *  # noqa: F401, F403
+from .shapes import *  # noqa: F401, F403
 
 
 # Set the bibtex entry to the article referenced in CITATION.rst.
@@ -25,10 +23,10 @@ def _get_bibtex():
         refs = citation.read().split('@software')[1:]
         if len(refs) == 0:
             return ''
-        bibtexreference = f"@software{refs[0]}"
+        bibtexreference = f'@software{refs[0]}'
     return bibtexreference
 
 
 __citation__ = __bibtex__ = _get_bibtex()
 
-del _get_bibtex  # noqa
+del _get_bibtex
