@@ -8,18 +8,18 @@ import operator
 
 import astropy.units as u
 
-from ..core.attributes import (ScalarPixCoord, PositiveScalar,
-                               PositiveScalarAngle, ScalarAngle,
-                               ScalarSkyCoord, RegionMetaDescr,
-                               RegionVisualDescr)
-from ..core.compound import CompoundPixelRegion
-from ..core.core import PixelRegion, SkyRegion
-from ..core.metadata import RegionMeta, RegionVisual
-from ..core.pixcoord import PixCoord
-from ..shapes.circle import CirclePixelRegion
-from ..shapes.ellipse import EllipsePixelRegion, EllipseSkyRegion
-from ..shapes.rectangle import RectanglePixelRegion, RectangleSkyRegion
-from .._utils.wcs_helpers import pixel_scale_angle_at_skycoord
+from regions._utils.wcs_helpers import pixel_scale_angle_at_skycoord
+from regions.core.attributes import (PositiveScalar, PositiveScalarAngle,
+                                     RegionMetaDescr, RegionVisualDescr,
+                                     ScalarAngle, ScalarPixCoord,
+                                     ScalarSkyCoord)
+from regions.core.compound import CompoundPixelRegion
+from regions.core.core import PixelRegion, SkyRegion
+from regions.core.metadata import RegionMeta, RegionVisual
+from regions.core.pixcoord import PixCoord
+from regions.shapes.circle import CirclePixelRegion
+from regions.shapes.ellipse import EllipsePixelRegion, EllipseSkyRegion
+from regions.shapes.rectangle import RectanglePixelRegion, RectangleSkyRegion
 
 __all__ = ['AnnulusPixelRegion', 'AsymmetricAnnulusPixelRegion',
            'AsymmetricAnnulusSkyRegion',
