@@ -4,10 +4,11 @@ Base class for all shape tests.
 """
 
 import numpy as np
-from numpy.testing import assert_equal, assert_allclose
 import pytest
+from numpy.testing import assert_allclose, assert_equal
 
-from ...core.pixcoord import PixCoord
+from regions._utils.optional_deps import HAS_MATPLOTLIB
+from regions.core.pixcoord import PixCoord
 
 
 class BaseTestRegion:
@@ -18,6 +19,12 @@ class BaseTestRegion:
     def test_str(self):
         assert str(self.reg) == self.expected_str
 
+    def test_del(self):
+        # test that Region shape attributes (descriptors) cannot be
+        # deleted)
+        with pytest.raises(AttributeError):
+            delattr(self.reg, self.reg._params[0])
+
 
 class BaseTestPixelRegion(BaseTestRegion):
 
@@ -66,6 +73,12 @@ class BaseTestPixelRegion(BaseTestRegion):
         assert_equal(actual[:, :len(self.inside)], True)
         assert_equal(actual[:, len(self.inside):], False)
 
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
+    def test_plot(self):
+        from matplotlib.artist import Artist
+        artist = self.reg.plot()
+        assert isinstance(artist, Artist)
+
 
 class BaseTestSkyRegion(BaseTestRegion):
     # TODO: here we should add inside/outside tests as above
