@@ -1,21 +1,21 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-import numpy as np
-from numpy.testing import assert_allclose, assert_equal
-import pytest
-
 import astropy.units as u
+import numpy as np
+import pytest
 from astropy.coordinates import SkyCoord
 from astropy.io import fits
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.utils.data import get_pkg_data_filename
 from astropy.wcs import WCS
+from numpy.testing import assert_allclose, assert_equal
 
-from ...core import PixCoord, RegionMeta, RegionVisual
-from ...tests.helpers import make_simple_wcs
-from ..._utils.optional_deps import HAS_MATPLOTLIB, MPL_VERSION  # noqa
-from ..rectangle import RectanglePixelRegion, RectangleSkyRegion
-from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
+from regions._utils.optional_deps import HAS_MATPLOTLIB, MPL_VERSION
+from regions.core import PixCoord, RegionMeta, RegionVisual
+from regions.shapes.rectangle import RectanglePixelRegion, RectangleSkyRegion
+from regions.shapes.tests.test_common import (BaseTestPixelRegion,
+                                              BaseTestSkyRegion)
+from regions.tests.helpers import make_simple_wcs
 
 
 @pytest.fixture(scope='session', name='wcs')
@@ -41,8 +41,8 @@ def test_corners():
     reg = RectanglePixelRegion(PixCoord(xc, yc), width=width, height=height,
                                angle=90 * u.deg)
     # simple case: rotate by 90
-    np.testing.assert_array_equal([(2.5, 1.), (2.5, 3.), (1.5, 3.), (1.5, 1.)],
-                                  reg.corners)
+    np.testing.assert_allclose([(2.5, 1.), (2.5, 3.), (1.5, 3.), (1.5, 1.)],
+                               reg.corners)
 
     reg = RectanglePixelRegion(center=PixCoord(xc, yc), width=width,
                                height=height, angle=0 * u.deg)
@@ -73,7 +73,7 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
         assert reg.center.xy == (3, 4)
         assert reg.width == 4
         assert reg.height == 3
-        assert_allclose(reg.angle.to_value("deg"), 5)
+        assert_allclose(reg.angle.to_value('deg'), 5)
         assert reg.meta == self.meta
         assert reg.visual == self.visual
 
@@ -94,7 +94,7 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
         assert reg_new.meta['text'] != self.reg.meta['text']
         assert reg_new.visual['color'] != self.reg.visual['color']
 
-    @pytest.mark.skipif('not HAS_MATPLOTLIB')
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_as_artist(self):
         patch = self.reg.as_artist()
         # Note: `reg.center` is the center, `patch.xy` is the lower-left
@@ -142,7 +142,7 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
 
         region = self.reg.copy(angle=0 * u.deg)
 
-        selector = region.as_mpl_selector(ax, callback=update_mask, sync=sync)  # noqa
+        selector = region.as_mpl_selector(ax, callback=update_mask, sync=sync)
 
         do_event(selector, 'press', xdata=7.3, ydata=4.4, button=1)
         do_event(selector, 'onmove', xdata=9.3, ydata=5.4, button=1)
@@ -177,7 +177,8 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
         """Test dragging of entire region from central handle and anywhere."""
 
         plt = pytest.importorskip('matplotlib.pyplot')
-        from matplotlib.testing.widgets import do_event  # click_and_drag  # MPL_VERSION >= 36
+        from matplotlib.testing.widgets import (
+            do_event)  # click_and_drag  # MPL_VERSION >= 36
 
         data = np.random.random((16, 16))
         mask = np.zeros_like(data)
@@ -231,7 +232,7 @@ class TestRectanglePixelRegion(BaseTestPixelRegion):
 
     @pytest.mark.parametrize('userargs',
                              ({'useblit': True},
-                              {'grab_range': 20, 'minspanx': 5,  'minspany': 4},
+                              {'grab_range': 20, 'minspanx': 5, 'minspany': 4},
                               {'props': {'facecolor': 'blue', 'linewidth': 2}},
                               {'twit': 'gumby'}))
     def test_mpl_selector_kwargs(self, userargs):
